# poxo
*(poco)*

*Pequeño y perezoso panda | Small and lazy panda*
[EN](#Intro) | [ES](#Introducción)

## Introducción

Esta librería esta enfocada a ser una herramienta para aprender prácticas de programación creando una copia simple de la conocida librería [pandas](https://github.com/pandas-dev/pandas) 


## Intro

This library is intended to be a learning tool for programming while creating a simple copy of the known library [pandas](https://github.com/pandas-dev/pandas)



## Ejemplo | Example

```python
import poxo as po

s = po.Series() 
```